<?php

/**
 * @file
 * Contains \Drupal\walkscore\Form\WalkScoreForm.
 */

namespace Drupal\walkscore\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\walkscore\WalkScore;

/**
 * WalkScore Settings Form
 */
class WalkScoreForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'walkscore_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('walkscore.settings');

    $form['walkscore_api'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#required' => TRUE,
      '#default_value' => $config->get('api_key'),
      '#description' => $this->t('Don\'t have a key? Sign up for one at <a href=":url">walkscore.com</a>.', [':url' => 'https://www.walkscore.com/professional/api-sign-up.php']),
    ];

    $form['walkscore_test'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Test Results'),
      '#options' => [],
      '#description' => WalkScore::printTest(),
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $this->messenger()
      ->addMessage($this->t("The WalkScore settings have been saved."));

    $this->configFactory->getEditable('walkscore.settings')
      ->set('api_key', $form_state->getValue("walkscore_api"))
      ->save();
  }
}
