<?php

namespace Drupal\walkscore\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\NumericFormatterBase;
use Drupal\walkscore\WalkScore;

/**
 * Plugin implementation of the 'WalkScore_default' formatter.
 *
 * @FieldFormatter(
 *   id = "WalkScore_default",
 *   label = @Translation("WalkScore text"),
 *   field_types = {
 *     "walkscore"
 *   }
 * )
 */
class WalkScoreFormatter extends NumericFormatterBase {

  // @todo: override settings form to allow user to choose short and long form
  // public function settingsForm(array $form, FormStateInterface $form_state) {
  // See https://api.drupal.org/api/drupal/core%21lib%21Drupal%21Core%21Field%21Plugin%21Field%21FieldFormatter%21NumericFormatterBase.php/8.2.x

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];

    $summary[] = $this->t('Displays the score and description.');

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {

    $elements = [];

    foreach ($items as $delta => $item) {
      $score = $this->numberFormat($item->value);

      $elements[$delta] = [
        '#markup' => "<div class='score'>" . $score . "</div>"
          . "<div class='desc'>" . WalkScore::getScoreDescription($score) . "</div>",
      ];
    }

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function numberFormat($number) {
    return floor($number);
  }

}
